@@ -48,7 +48,7 @@ class ClipboardIcon(RadioToolButton):
         self.props.sensitive = False
         self.props.active = False
         self._notif_icon = None
-        self._current_percent = None
+        self._current_percent = 0
 
         self._icon = Icon()
         color = profile.get_color()
@@ -62,7 +62,7 @@ class ClipboardIcon(RadioToolButton):
         cb_service.connect('object-selected', self._object_selected_cb)
 
         child = self.get_child()
-        child.connect('drag_data_get', self._drag_data_get_cb)
+        child.connect('drag-data-get', self._drag_data_get_cb)
         self.connect('notify::active', self._notify_active_cb)
 
     def create_palette(self):
@@ -152,11 +152,12 @@ class ClipboardIcon(RadioToolButton):
             self.props.sensitive = True
 
         # Clipboard object became complete. Make it the active one.
-        if self._current_percent < 100 and cb_object.get_percent() == 100:
+        percent = cb_object.get_percent()
+        if self._current_percent < 100 and percent == 100:
             self.props.active = True
             self.show_notification()
 
-        self._current_percent = cb_object.get_percent()
+        self._current_percent = percent
 
     def _object_selected_cb(self, cb_service, object_id):
         if object_id != self._cb_object.get_id():
@@ -174,7 +175,7 @@ class ClipboardIcon(RadioToolButton):
         frame = jarabe.frame.get_view()
         self._timeout_id = frame.add_notification(
             self._notif_icon, Gtk.CornerType.BOTTOM_LEFT)
-        self._notif_icon.connect('drag_data_get', self._drag_data_get_cb)
+        self._notif_icon.connect('drag-data-get', self._drag_data_get_cb)
         self._notif_icon.connect('drag-begin', self._drag_begin_cb)
         self._notif_icon.drag_source_set(Gdk.ModifierType.BUTTON1_MASK,
                                          self._get_targets(),
@@ -197,7 +198,7 @@ class ClipboardIcon(RadioToolButton):
 
     def _get_targets(self):
         targets = []
-        for format_type in self._cb_object.get_formats().keys():
+        for format_type in list(self._cb_object.get_formats().keys()):
             targets.append(Gtk.TargetEntry.new(format_type,
                                                Gtk.TargetFlags.SAME_APP, 0))
         return targets
