@@ -96,8 +96,7 @@ def _get_toolkit_path(bundle_path, bundle_id):
         sugar_web_path = os.path.join(bundle_path, 'lib', 'sugar-web')
         if os.path.exists(sugar_web_path):
             return sugar_web_path
-        else:
-            return None
+        return None
 
     if _is_gtk3_activity(bundle_path, bundle_id):
         sugar_module = 'sugar3'
@@ -335,6 +334,7 @@ class ViewSource(Gtk.Window):
             os.unlink(document_path)
 
         self._gdk_window.set_cursor(Gdk.Cursor(Gdk.CursorType.LEFT_PTR))
+        Gdk.flush()
 
     def __key_press_event_cb(self, window, event):
         keyname = Gdk.keyval_name(event.keyval)
@@ -366,7 +366,7 @@ class DocumentButton(RadioToolButton):
 
         self.props.tooltip = _('Instance Source')
 
-        settings = Gio.Settings('org.sugarlabs.user')
+        settings = Gio.Settings.new('org.sugarlabs.user')
         self._color = settings.get_string('color')
         icon = Icon(file=file_name,
                     pixel_size=style.STANDARD_ICON_SIZE,
@@ -423,6 +423,7 @@ class DocumentButton(RadioToolButton):
 
         gdk_window = self.get_root_window()
         gdk_window.set_cursor(cursor)
+        Gdk.flush()
 
     def __copy_to_home_cb(self, menu_item, copy_alert=None):
         """Make a local copy of the activity bundle in user_activities_path"""
