@@ -39,6 +39,7 @@ def _translate_language(msg):
 def _translate_country(msg):
     return gettext.dgettext('iso_3166', msg)
 
+
 CLASS = 'Language'
 ICON = 'module-language'
 TITLE = gettext.gettext('Language')
@@ -140,7 +141,7 @@ class Language(SectionView):
                     locale_country = country
 
         language_palette = []
-        key_list = self._language_dict.keys()
+        key_list = list(self._language_dict.keys())
         for language_key in sorted(key_list):
             language_palette.append(
                 {'label': self._language_dict[language_key],
@@ -327,7 +328,7 @@ class Language(SectionView):
     def _language_changed(self, widget, event, item):
         i = item['index']
 
-        for language_key in self._language_dict.keys():
+        for language_key in list(self._language_dict.keys()):
             if self._language_dict[language_key] == item['label']:
                 new_country_list = \
                     self._build_country_list(language_key, idx=i)
@@ -485,6 +486,7 @@ class BlackLabel(PaletteMenuItem):
         self.set_label(text_label)
 
     def set_label(self, text_label):
+        text_label = GLib.markup_escape_text(text_label)
         text = '<span foreground="%s">' % style.COLOR_BLACK.get_html() + \
             text_label + '</span>'
         self.label.set_markup(text)
